
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),

        Asset( "ANIM", "anim/geno_sans.zip" ),
		Asset( "ANIM", "anim/geno_sans_formal.zip" ),
		Asset( "ANIM", "anim/geno_sans_shadow.zip" ),
		Asset( "ANIM", "anim/geno_sans_survivor.zip" ),
        Asset( "ANIM", "anim/ghost_geno_sans_build.zip" ),
}
local prefabs = {}

-- Custom starting items
local start_inv = {"pizza",
    "completelyregularattack",
	"sans_magic",
}


-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when loading or reviving from ghost (optional)
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
end

local master_postinit = function(inst)
    inst:AddComponent("sanityaura")
    inst.components.sanityaura.aurafn = function(inst, observer)
        if observer.prefab == "thegreatpapyrus" then
            return TUNING.SANITYAURA_TINY
        end
        return 0
    end
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)

    if not inst:HasTag("playerghost") then
        onbecamehuman(inst)
    end
end

-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "geno_sans.tex" )
	-- Access to geno_sansational recipes
		inst:AddTag("geno_sansational")
		inst:AddTag("reader")
end

-- Deals poison damage.
local function DoPoisonDamage(inst)
inst.components.health:DoDelta(-1, true, "poison")
--Blip for 1/3 of a second upon poison
inst.AnimState:SetMultColour(1,0,1,1)
	inst:DoTaskInTime(((TUNING.POISON_DPS)*.5), function(inst) inst.AnimState:SetMultColour(1,1,1,1) end)
end

-- OnAttackOther, deal poison damage every .33 seconds.
local function onattackother(inst, data)
if data.target and data.target.components.health and not data.target.components.health:IsDead() then
-- If config says false; no target players. 
if not data.target:HasTag("player") or not TUNING.PLAYER_POISON == false then
-- Can't already be poisoned.
if data.target.poisontask == nil then
-- If conditions met; deal DoPoisonDamage value 3 times per second.
data.target.poisontask = data.target:DoPeriodicTask(TUNING.POISON_DPS, DoPoisonDamage)
-- End poison damage @ 30 seconds. Deals 90 damage total (30 seconds * 1 damage * 3 times per second).
data.target.poisonwearofftask = data.target:DoTaskInTime(30, function(inst) inst.poisontask:Cancel() inst.poisontask = nil end)
			end
		end
	end
end


-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "sans"
	
	inst:AddComponent("reader")
	
	-- Stats	
	inst.components.health:SetMaxHealth(230)
	inst.components.hunger:SetMax(130)
	inst.components.sanity:SetMax(195)
	
	inst.components.builder.science_bonus = 1
	
	inst.components.temperature.mintemp = 20
	
	local WalkSpeed = (TUNING.WILSON_WALK_SPEED * 1.5)
	local RunSpeed = (TUNING.WILSON_RUN_SPEED * 1.5)
	
	inst.components.locomotor.walkspeed = 5
	inst.components.locomotor.runspeed = 7
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 4
	
	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst:ListenForEvent("onattackother", onattackother)
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
		--sanity gain near pap
	inst:AddComponent("sanityaura")

inst.components.sanityaura.aurafn = function(inst, observer)

if observer.prefab == "thegreatpapyrus" then

return TUNING.SANITYAURA_TINY

end

return 0

end
end

return MakePlayerCharacter("geno_sans", prefabs, assets, common_postinit, master_postinit, start_inv)
